@@ -27,7 +27,7 @@
 #ifndef __DFT_CODELET_H__
 #define __DFT_CODELET_H__
 
-#include "ifftw.h"
+#include "kernel/ifftw.h"
 
 /**************************************************************
  * types of codelets
@@ -98,7 +98,15 @@ void X(kdft_difsq_register)(planner *p, kdftwsq codelet, const ct_desc *desc);
 extern const solvtab X(solvtab_dft_standard);
 extern const solvtab X(solvtab_dft_sse2);
 extern const solvtab X(solvtab_dft_avx);
+extern const solvtab X(solvtab_dft_avx_128_fma);
+extern const solvtab X(solvtab_dft_avx2);
+extern const solvtab X(solvtab_dft_avx2_128);
+extern const solvtab X(solvtab_dft_avx512);
+extern const solvtab X(solvtab_dft_kcvi);
 extern const solvtab X(solvtab_dft_altivec);
+extern const solvtab X(solvtab_dft_vsx);
 extern const solvtab X(solvtab_dft_neon);
+extern const solvtab X(solvtab_dft_generic_simd128);
+extern const solvtab X(solvtab_dft_generic_simd256);
 
 #endif				/* __DFT_CODELET_H__ */
