@@ -1,7 +1,7 @@
 (*
  * Copyright (c) 1997-1999 Massachusetts Institute of Technology
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-14 Matteo Frigo
+ * Copyright (c) 2003, 2007-14 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,10 +15,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *)
-(* $Id: magic.ml,v 1.12 2003/03/15 20:29:42 stevenj Exp $ *)
 
 (* magic parameters *)
 let verbose = ref false
@@ -29,13 +28,13 @@ let circular_min = ref 64
 let rader_min = ref 13
 let rader_list = ref [5]
 let alternate_convolution = ref 17
+let threemult = ref false
 let inline_single = ref true
 let inline_loads = ref false
 let inline_loads_constants = ref false
 let inline_constants = ref true
 let trivial_stores = ref false
 let locations_are_special = ref false
-let wsquare = ref false
 let strength_reduce_mul = ref false
 let number_of_variables = ref 4
 let codelet_name = ref "unnamed"
@@ -51,6 +50,16 @@ let asched_dump_file = ref ""
 let lisp_syntax = ref false
 let network_transposition = ref true
 let inklude = ref ""
+let generic_arith = ref false
+let reorder_insns = ref false
+let reorder_loads = ref false
+let reorder_stores = ref false
+let precompute_twiddles = ref false
+let newsplit = ref false
+let standalone = ref false
+let pipeline_latency = ref 0
+let schedule_for_pipeline = ref false
+let generate_bytw = ref true
 
 (* command-line parser for magic parameters *)
 let undocumented = " Undocumented voodoo parameter"
@@ -62,6 +71,7 @@ let set_string var = Arg.String(fun s -> var := s)
 
 let speclist = [
   "-name", set_string codelet_name, " set codelet name";
+  "-standalone", set_bool standalone, " standalone codelet (no desc)";
   "-include", set_string inklude, undocumented;
 
   "-verbose", set_bool verbose, " Enable verbose logging messages to stderr";
@@ -69,6 +79,9 @@ let speclist = [
   "-rader-min", set_int rader_min,
   "<n> : Use Rader's algorithm for prime sizes >= <n>";
 
+  "-threemult", set_bool threemult, 
+  " Use 3-multiply complex multiplications";
+
   "-karatsuba-min", set_int karatsuba_min, undocumented;
   "-karatsuba-variant", set_int karatsuba_variant, undocumented;
   "-circular-min", set_int circular_min, undocumented;
@@ -86,10 +99,18 @@ let speclist = [
   "-alternate-convolution", set_int alternate_convolution, undocumented;
   "-deep-collect-depth", set_int deep_collect_depth, undocumented;
   "-schedule-type", set_int schedule_type, undocumented;
+  "-pipeline-latency", set_int pipeline_latency, undocumented;
+  "-schedule-for-pipeline", set_bool schedule_for_pipeline, undocumented;
 
   "-dif-split-radix", set_bool dif_split_radix, undocumented;
   "-dit-split-radix", unset_bool dif_split_radix, undocumented;
 
+  "-generic-arith", set_bool generic_arith, undocumented;
+  "-no-generic-arith", unset_bool generic_arith, undocumented;
+
+  "-precompute-twiddles", set_bool precompute_twiddles, undocumented;
+  "-no-precompute-twiddles", unset_bool precompute_twiddles, undocumented;
+
   "-inline-single", set_bool inline_single, undocumented;
   "-no-inline-single", unset_bool inline_single, undocumented;
 
@@ -115,6 +136,15 @@ let speclist = [
   "-network-transposition", set_bool network_transposition, undocumented;
   "-no-network-transposition", unset_bool network_transposition, undocumented;
 
+  "-reorder-insns", set_bool reorder_insns, undocumented;
+  "-no-reorder-insns", unset_bool reorder_insns, undocumented;
+  "-reorder-loads", set_bool reorder_loads, undocumented;
+  "-no-reorder-loads", unset_bool reorder_loads, undocumented;
+  "-reorder-stores", set_bool reorder_stores, undocumented;
+  "-no-reorder-stores", unset_bool reorder_stores, undocumented;
+
+  "-newsplit", set_bool newsplit, undocumented;
+
   "-vneg", set_bool vneg, undocumented;
   "-fma", set_bool enable_fma, undocumented;
   "-no-fma", unset_bool enable_fma, undocumented;
@@ -124,8 +154,8 @@ let speclist = [
   "-strength-reduce-mul", set_bool strength_reduce_mul, undocumented;
   "-no-strength-reduce-mul", unset_bool strength_reduce_mul, undocumented;
 
-  "-wsquare", set_bool wsquare, undocumented;
-  "-no-wsquare", unset_bool wsquare, undocumented;
+  "-generate-bytw", set_bool generate_bytw, undocumented;
+  "-no-generate-bytw", unset_bool generate_bytw, undocumented;
 ] 
    
 
