@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2007-11 Matteo Frigo
- * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-14 Matteo Frigo
+ * Copyright (c) 2003, 2007-14 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 /* common routines for Cooley-Tukey algorithms */
 
-#include "ifftw.h"
+#include "kernel/ifftw.h"
 
 #define POW2P(n) (((n) > 0) && (((n) & ((n) - 1)) == 0))
 
