@@ -8,8 +8,8 @@
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
-#include "fftw-bench.h"
 #include "fftw3-mpi.h"
+#include "tests/fftw-bench.h"
 
 #if defined(BENCHFFT_SINGLE)
 #  define BENCH_MPI_TYPE MPI_FLOAT
@@ -340,7 +340,7 @@ static int tensor_rowmajor_transposedp(bench_tensor *t)
      bench_iodim *d;
      int i;
 
-     BENCH_ASSERT(FINITE_RNK(t->rnk));
+     BENCH_ASSERT(BENCH_FINITE_RNK(t->rnk));
      if (t->rnk < 2)
 	  return 0;
 
@@ -736,13 +736,13 @@ FFTW(plan) mkplan(bench_problem *p, unsigned flags)
      FFTW(destroy_plan)(plan_scramble_in); plan_scramble_in = 0;
      FFTW(destroy_plan)(plan_unscramble_out); plan_unscramble_out = 0;
      if (p->scrambled_in) {
-	  if (p->sz->rnk == 1) 
+	  if (p->sz->rnk == 1 && p->sz->dims[0].n != 1) 
 	       flags |= FFTW_MPI_SCRAMBLED_IN;
 	  else
 	       flags |= FFTW_MPI_TRANSPOSED_IN;
      }
      if (p->scrambled_out) {
-	  if (p->sz->rnk == 1) 
+	  if (p->sz->rnk == 1 && p->sz->dims[0].n != 1) 
 	       flags |= FFTW_MPI_SCRAMBLED_OUT;
 	  else
 	       flags |= FFTW_MPI_TRANSPOSED_OUT;
